==> php81-nextcloud-26.0.5.tgz: share/nextcloud/apps/activity/l10n/es_EC.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "Home" : "Inicio",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Open {filename}" : "Abrir {filename}",
    "Activity" : "Actividad",
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "Recent activity" : "Actividad reciente",
    "More activities" : "Más actividades",
    "Daily activity summary for %s" : "Resumen de la actividad diaria al %s",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Activity at %s" : "Actividad en %s",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "Mail" : "Correo",
    "Push" : "Push",
    "Notifications" : "Notificaciones",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite a las personas ver un registro de actividades sobre ellas, sus archivos u otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta aplicación permite a las personas ver acciones relacionadas con sus archivos y datos en Nextcloud. Cada persona puede configurar sus ajustes de actividad individuales en la configuración personal, para elegir qué actividades deben enviarse a teléfonos móviles, enviarse por correo electrónico o si se debe enviar un resumen diario cada mañana. Más información está disponible en la documentación de Actividad.",
    "Activity notification configuration" : "Configuración de notificaciones de actividad",
    "Send email" : "Enviar correo electrónico",
    "Send push notification" : "Enviar notificación push",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividades",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "No activity yet" : "Aún no tiene actividad",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar emails de notificación",
    "Choose for which activities you want to get an email or push notification." : "Elija para qué actividades desea recibir un email o una notificación push.",
    "Choose for which activities you want to get a push notification." : "Elija para qué actividades desea recibir una notificación push.",
    "Daily activity summary" : "Resumen diario de actividad",
    "Send daily activity summary in the morning" : "Enviar resumen de actividad diaria por la mañana",
    "Activities" : "Actividades",
    "No activities" : "Sin actividades",
    "Default settings" : "Configuraciones predeterminadas",
    "Configure the default notification settings for new accounts." : "Configurar los ajustes de notificación predeterminados para nuevas cuentas.",
    "Unable to save the settings" : "No se pueden guardar los ajustes.",
    "Activity feed" : "Fuente de actividad",
    "Activity settings" : "Configuración de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Copy RSS feed link" : "Copiar enlace de fuente RSS",
    "Personal notification settings" : "Ajustes de notificación personal.",
    "No more events to load" : "No hay más eventos por cargar",
    "This application enables users to view a log of activities about them or about files." : "Esta aplicación permite a los usuarios ver un registro de sus actividades o de los archivos.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Esta aplicación permite a los usuarios ver acciones relacionadas con sus archivos en Nextcloud.\n\t\tUna vez habilitado, los usuarios verán un nuevo ícono \"Actividad\" en su menú de aplicaciones.\n\t\tAl hacer clic, aparece una nueva página para que los usuarios realicen un seguimiento de la actividad relacionada con los archivos: desde archivos nuevos hasta archivos eliminados, mover, cambiar el nombre, actualizaciones y actividad compartida.\n\t\tEl usuario puede configurar sus ajustes de actividad individuales en su menú personal.\n\t\tEsto establece el tipo de actividad para registrar, así como si el usuario ve sus propias actividades,\n\t\tsi estos solo están disponibles en línea y si reciben un resumen de correo electrónico de forma regular.\n\t\tMás información está disponible en la documentación de la Actividad.",
    "Unable to load the activity list" : "No se puede cargar la lista de actividades",
    "Configure the default notification settings for new users." : "Configure los ajustes de notificación predeterminados para nuevos usuarios."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php81-nextcloud-30.0.5.tgz: share/nextcloud/apps/activity/l10n/es_EC.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Activity feed" : "Fuente de actividad",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "Recent activity" : "Actividad reciente",
    "No activities" : "Sin actividades",
    "More activities" : "Más actividades",
    "Daily activity summary for %s" : "Resumen de la actividad diaria al %s",
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Activity at %s" : "Actividad en %s",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "Mail" : "Correo",
    "Push" : "Push",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite a las personas ver un registro de actividades sobre ellas, sus archivos u otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta aplicación permite a las personas ver acciones relacionadas con sus archivos y datos en Nextcloud. Cada persona puede configurar sus ajustes de actividad individuales en la configuración personal, para elegir qué actividades deben enviarse a teléfonos móviles, enviarse por correo electrónico o si se debe enviar un resumen diario cada mañana. Más información está disponible en la documentación de Actividad.",
    "Activity notification configuration" : "Configuración de notificaciones de actividad",
    "Send email" : "Enviar correo electrónico",
    "Send push notification" : "Enviar notificación push",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividades",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Comentaste",
    "Message deleted by author" : "Mensaje eliminado por el autor",
    "Open {filename}" : "Abrir {filename}",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "No activity yet" : "Aún no tiene actividad",
    "Activity settings" : "Configuración de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Copy RSS feed link" : "Copiar enlace de fuente RSS",
    "Personal notification settings" : "Ajustes de notificación personal.",
    "Unable to load the activity list" : "No se puede cargar la lista de actividades",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar emails de notificación",
    "Choose for which activities you want to get an email or push notification." : "Elija para qué actividades desea recibir un email o una notificación push.",
    "Choose for which activities you want to get a push notification." : "Elija para qué actividades desea recibir una notificación push.",
    "Daily activity summary" : "Resumen diario de actividad",
    "Send daily activity summary in the morning" : "Enviar resumen de actividad diaria por la mañana",
    "Default settings" : "Configuraciones predeterminadas",
    "Configure the default notification settings for new accounts." : "Configurar los ajustes de notificación predeterminados para nuevas cuentas.",
    "Unable to save the settings" : "No se pueden guardar los ajustes.",
    "No more events to load" : "No hay más eventos por cargar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
